The guides are meant as deeper dives into specific topics. Although we try to write each guide as a standalone document, some parts of a guide may build on top of a previous one, e.g. the installation guide is expected to be followed.

# Guides

   * [Installing](./installing)
   * [Your first Solara app](./first-app)
   * [Multi page support](./multipage)
   * [Layouts](./layout)
